@@ -2,9 +2,10 @@ package POE::Component::CPAN::YACSmoke;
 
 use strict;
 use POE qw(Wheel::Run);
+use Storable;
 use vars qw($VERSION);
 
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 my $GOT_KILLFAM;
 
@@ -61,6 +62,20 @@ sub pending_jobs {
   return @{ $_[0]->{job_queue} };
 }
 
+sub current_job {
+  my $self = shift;
+  return unless $self->{_current_job};
+  my $item = Storable::dclone( $self->{_current_job} );
+  return $item;
+}
+
+sub current_log {
+  my $self = shift;
+  return unless $self->{_wheel_log};
+  my $item = Storable::dclone( $self->{_wheel_log} );
+  return $item;
+}
+
 sub shutdown {
   my $self = shift;
   $poe_kernel->post( $self->{session_id}, 'shutdown' );
@@ -597,6 +612,14 @@ Returns the POE::Session ID of the component's session.
 In a scalar context returns the number of currently pending jobs. In a list context, returns a list of hashrefs
 which are the jobs currently waiting in the job queue.
 
+=item current_job
+
+Returns a hashref containing details of the currently executing smoke job. Returns undef if there isn't a job currently running.
+
+=item current_log
+
+Returns an arrayref of log output from the currently executing smoke job. Returns undef if there isn't a job currently running.
+
 =item shutdown
 
 Terminates the component. Any pending jobs are cancelled and the currently running job is allowed to complete gracefully. Requires no additional parameters.
